@@ -1,8 +1,6 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING
-from typing import Generic
-from typing import TypeVar
+from typing import TYPE_CHECKING, Generic, TypeVar
 
 if TYPE_CHECKING:
     from narwhals.expr import Expr
@@ -43,7 +41,7 @@ class ExprDateTimeNamespace(Generic[ExprT]):
             │ 2027-12-13 │
             └────────────┘
         """
-        return self._expr._with_elementwise_op(
+        return self._expr._with_elementwise(
             lambda plx: self._expr._to_compliant_expr(plx).dt.date()
         )
 
@@ -72,7 +70,7 @@ class ExprDateTimeNamespace(Generic[ExprT]):
             |1 2065-01-01  2065|
             └──────────────────┘
         """
-        return self._expr._with_elementwise_op(
+        return self._expr._with_elementwise(
             lambda plx: self._expr._to_compliant_expr(plx).dt.year()
         )
 
@@ -98,7 +96,7 @@ class ExprDateTimeNamespace(Generic[ExprT]):
             a: [[1978-06-01 00:00:00.000000,2065-01-01 00:00:00.000000]]
             month: [[6,1]]
         """
-        return self._expr._with_elementwise_op(
+        return self._expr._with_elementwise(
             lambda plx: self._expr._to_compliant_expr(plx).dt.month()
         )
 
@@ -124,7 +122,7 @@ class ExprDateTimeNamespace(Generic[ExprT]):
             a: [[1978-06-01 00:00:00.000000,2065-01-01 00:00:00.000000]]
             day: [[1,1]]
         """
-        return self._expr._with_elementwise_op(
+        return self._expr._with_elementwise(
             lambda plx: self._expr._to_compliant_expr(plx).dt.day()
         )
 
@@ -159,7 +157,7 @@ class ExprDateTimeNamespace(Generic[ExprT]):
             |└─────────────────────┴──────┘|
             └──────────────────────────────┘
         """
-        return self._expr._with_elementwise_op(
+        return self._expr._with_elementwise(
             lambda plx: self._expr._to_compliant_expr(plx).dt.hour()
         )
 
@@ -184,7 +182,7 @@ class ExprDateTimeNamespace(Generic[ExprT]):
             0 1978-01-01 01:01:00       1
             1 2065-01-01 10:20:00      20
         """
-        return self._expr._with_elementwise_op(
+        return self._expr._with_elementwise(
             lambda plx: self._expr._to_compliant_expr(plx).dt.minute()
         )
 
@@ -215,7 +213,7 @@ class ExprDateTimeNamespace(Generic[ExprT]):
             a: [[1978-01-01 01:01:01.000000,2065-01-01 10:20:30.000000]]
             second: [[1,30]]
         """
-        return self._expr._with_elementwise_op(
+        return self._expr._with_elementwise(
             lambda plx: self._expr._to_compliant_expr(plx).dt.second()
         )
 
@@ -248,7 +246,7 @@ class ExprDateTimeNamespace(Generic[ExprT]):
             a: [[1978-01-01 01:01:01.000000,2065-01-01 10:20:30.067000]]
             millisecond: [[0,67]]
         """
-        return self._expr._with_elementwise_op(
+        return self._expr._with_elementwise(
             lambda plx: self._expr._to_compliant_expr(plx).dt.millisecond()
         )
 
@@ -281,7 +279,7 @@ class ExprDateTimeNamespace(Generic[ExprT]):
             a: [[1978-01-01 01:01:01.000000,2065-01-01 10:20:30.067000]]
             microsecond: [[0,67000]]
         """
-        return self._expr._with_elementwise_op(
+        return self._expr._with_elementwise(
             lambda plx: self._expr._to_compliant_expr(plx).dt.microsecond()
         )
 
@@ -314,7 +312,7 @@ class ExprDateTimeNamespace(Generic[ExprT]):
             a: [[1978-01-01 01:01:01.000000,2065-01-01 10:20:30.067000]]
             nanosecond: [[0,67000000]]
         """
-        return self._expr._with_elementwise_op(
+        return self._expr._with_elementwise(
             lambda plx: self._expr._to_compliant_expr(plx).dt.nanosecond()
         )
 
@@ -341,7 +339,7 @@ class ExprDateTimeNamespace(Generic[ExprT]):
             |1 2020-08-03            216|
             └───────────────────────────┘
         """
-        return self._expr._with_elementwise_op(
+        return self._expr._with_elementwise(
             lambda plx: self._expr._to_compliant_expr(plx).dt.ordinal_day()
         )
 
@@ -368,7 +366,7 @@ class ExprDateTimeNamespace(Generic[ExprT]):
             |1 2020-08-03           1|
             └────────────────────────┘
         """
-        return self._expr._with_elementwise_op(
+        return self._expr._with_elementwise(
             lambda plx: self._expr._to_compliant_expr(plx).dt.weekday()
         )
 
@@ -404,7 +402,7 @@ class ExprDateTimeNamespace(Generic[ExprT]):
             │ 20m 40s      ┆ 20              │
             └──────────────┴─────────────────┘
         """
-        return self._expr._with_elementwise_op(
+        return self._expr._with_elementwise(
             lambda plx: self._expr._to_compliant_expr(plx).dt.total_minutes()
         )
 
@@ -440,7 +438,7 @@ class ExprDateTimeNamespace(Generic[ExprT]):
             │ 20s 40ms     ┆ 20              │
             └──────────────┴─────────────────┘
         """
-        return self._expr._with_elementwise_op(
+        return self._expr._with_elementwise(
             lambda plx: self._expr._to_compliant_expr(plx).dt.total_seconds()
         )
 
@@ -481,7 +479,7 @@ class ExprDateTimeNamespace(Generic[ExprT]):
             │ 20040µs      ┆ 20                   │
             └──────────────┴──────────────────────┘
         """
-        return self._expr._with_elementwise_op(
+        return self._expr._with_elementwise(
             lambda plx: self._expr._to_compliant_expr(plx).dt.total_milliseconds()
         )
 
@@ -519,7 +517,7 @@ class ExprDateTimeNamespace(Generic[ExprT]):
             a: [[10,1200]]
             a_total_microseconds: [[10,1200]]
         """
-        return self._expr._with_elementwise_op(
+        return self._expr._with_elementwise(
             lambda plx: self._expr._to_compliant_expr(plx).dt.total_microseconds()
         )
 
@@ -556,7 +554,7 @@ class ExprDateTimeNamespace(Generic[ExprT]):
             0 2024-01-01 00:00:00.000000001                       NaN
             1 2024-01-01 00:00:00.000000002                       1.0
         """
-        return self._expr._with_elementwise_op(
+        return self._expr._with_elementwise(
             lambda plx: self._expr._to_compliant_expr(plx).dt.total_nanoseconds()
         )
 
@@ -605,12 +603,7 @@ class ExprDateTimeNamespace(Generic[ExprT]):
             >>> import polars as pl
             >>> import narwhals as nw
             >>> df_native = pl.DataFrame(
-            ...     {
-            ...         "a": [
-            ...             datetime(2020, 3, 1),
-            ...             datetime(2020, 5, 1),
-            ...         ]
-            ...     }
+            ...     {"a": [datetime(2020, 3, 1), datetime(2020, 5, 1)]}
             ... )
             >>> df = nw.from_native(df_native)
             >>> df.select(nw.col("a").dt.to_string("%Y/%m/%d %H:%M:%S"))
@@ -628,7 +621,7 @@ class ExprDateTimeNamespace(Generic[ExprT]):
             |└─────────────────────┘|
             └───────────────────────┘
         """
-        return self._expr._with_elementwise_op(
+        return self._expr._with_elementwise(
             lambda plx: self._expr._to_compliant_expr(plx).dt.to_string(format)
         )
 
@@ -659,10 +652,8 @@ class ExprDateTimeNamespace(Generic[ExprT]):
             0 2024-01-01 00:00:00+05:45
             1 2024-01-02 00:00:00+05:45
         """
-        return self._expr._with_elementwise_op(
-            lambda plx: self._expr._to_compliant_expr(plx).dt.replace_time_zone(
-                time_zone
-            ),
+        return self._expr._with_elementwise(
+            lambda plx: self._expr._to_compliant_expr(plx).dt.replace_time_zone(time_zone)
         )
 
     def convert_time_zone(self, time_zone: str) -> ExprT:
@@ -698,10 +689,8 @@ class ExprDateTimeNamespace(Generic[ExprT]):
         if time_zone is None:
             msg = "Target `time_zone` cannot be `None` in `convert_time_zone`. Please use `replace_time_zone(None)` if you want to remove the time zone."
             raise TypeError(msg)
-        return self._expr._with_elementwise_op(
-            lambda plx: self._expr._to_compliant_expr(plx).dt.convert_time_zone(
-                time_zone
-            ),
+        return self._expr._with_elementwise(
+            lambda plx: self._expr._to_compliant_expr(plx).dt.convert_time_zone(time_zone)
         )
 
     def timestamp(self, time_unit: TimeUnit = "us") -> ExprT:
@@ -743,8 +732,8 @@ class ExprDateTimeNamespace(Generic[ExprT]):
                 f"\n\nExpected one of {{'ns', 'us', 'ms'}}, got {time_unit!r}."
             )
             raise ValueError(msg)
-        return self._expr._with_elementwise_op(
-            lambda plx: self._expr._to_compliant_expr(plx).dt.timestamp(time_unit),
+        return self._expr._with_elementwise(
+            lambda plx: self._expr._to_compliant_expr(plx).dt.timestamp(time_unit)
         )
 
     def truncate(self, every: str) -> ExprT:
@@ -790,6 +779,53 @@ class ExprDateTimeNamespace(Generic[ExprT]):
             |└─────────────────────┴─────────────────────┘|
             └─────────────────────────────────────────────┘
         """
-        return self._expr._with_elementwise_op(
-            lambda plx: self._expr._to_compliant_expr(plx).dt.truncate(every),
+        return self._expr._with_elementwise(
+            lambda plx: self._expr._to_compliant_expr(plx).dt.truncate(every)
+        )
+
+    def offset_by(self, by: str) -> ExprT:
+        """Offset this date by a relative time offset.
+
+        Arguments:
+            by: The offset. Must be of form `<multiple><unit>`,
+                where `multiple` is a positive integer and `unit` is one of
+
+                - 'ns': nanosecond.
+                - 'us': microsecond.
+                - 'ms': millisecond.
+                - 's': second.
+                - 'm': minute.
+                - 'h': hour.
+                - 'd': day.
+                - 'mo': month.
+                - 'q': quarter.
+                - 'y': year.
+
+        Returns:
+            Expression of data type `Date` or `Datetime`.
+
+        Examples:
+            >>> from datetime import datetime
+            >>> import polars as pl
+            >>> import narwhals as nw
+            >>> df_native = pl.DataFrame({"datetime": [datetime(2021, 3, 1, 12, 34)]})
+            >>> df = nw.from_native(df_native)
+            >>> df.with_columns(
+            ...     nw.col("datetime").dt.offset_by("1h").alias("datetime_offset_by_1h")
+            ... )
+            ┌───────────────────────────────────────────────┐
+            |              Narwhals DataFrame               |
+            |-----------------------------------------------|
+            |shape: (1, 2)                                  |
+            |┌─────────────────────┬───────────────────────┐|
+            |│ datetime            ┆ datetime_offset_by_1h │|
+            |│ ---                 ┆ ---                   │|
+            |│ datetime[μs]        ┆ datetime[μs]          │|
+            |╞═════════════════════╪═══════════════════════╡|
+            |│ 2021-03-01 12:34:00 ┆ 2021-03-01 13:34:00   │|
+            |└─────────────────────┴───────────────────────┘|
+            └───────────────────────────────────────────────┘
+        """
+        return self._expr._with_elementwise(
+            lambda plx: self._expr._to_compliant_expr(plx).dt.offset_by(by)
         )
